"""
Dastavez - Document AI & Browser Agents by Rotavision

This is a namespace placeholder. Please install the main `rotavision` package.

    pip install rotavision

Documentation: https://rotavision.com/docs
"""

__version__ = "0.0.1"

raise ImportError(
    "This is a namespace placeholder package. "
    "Please install the main package: pip install rotavision"
)
